gc3libs.application.gamess — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »

# gc3libs.application.gamess

Specialized support for computational jobs running GAMESS-US.

class `gc3libs.application.gamess.` `GamessAppPotApplication`(inp_file_path, *other_input_files, **extra_args)

  Specialized AppPotApplication object to submit computational jobs running GAMESS-US.

  This class makes no check or guarantee that a GAMESS-US executable will be available in the executing AppPot instance: the apppot_img and apppot_tag keyword arguments can be used to select the AppPot system image to run this application; see the `AppPotApplication` for information.

  The __init__ construction interface is compatible with the one used in `GamessApplication`. The only required parameter for construction is the input file name; any other argument names an additional input file, that is added to the Application.inputs list, but not otherwise treated specially.

  Any other keyword parameter that is valid in the Application class can be used here as well, with the exception of input and output. Note that a GAMESS-US job is always submitted with join = True, therefore any stderr setting is ignored.

class `gc3libs.application.gamess.` `GamessApplication`(inp_file_path, *other_input_files, **extra_args)

  Specialized Application object to submit computational jobs running GAMESS-US.

  The only required parameter for construction is the input file name; subsequent positional arguments are additional input files, that are added to the Application.inputs list, but not otherwise treated specially.

  The verno parameter is used to request a specific version of GAMESS-US; if the default value `None` is used, the default version of GAMESS-US at the executing site is run.

  Any other keyword parameter that is valid in the Application class can be used here as well, with the exception of input and output. Note that a GAMESS-US job is always submitted with join = True, therefore any stderr setting is ignored.

  `terminated`()

    Append to log the termination status line as extracted from the GAMESS ‘.out’ file.

    The job exit code .execution.exitcode is (re)set according to the following table:

    Exit code | Meaning
    --- | ---
    0 | the output file contains the string `EXECUTION OF GAMESS TERMINATED normally`
    1 | the output file contains the string `EXECUTION OF GAMESS TERMINATED -ABNORMALLY-`
    2 | the output file contains the string `ddikick exited unexpectedly`
    70 (os.EX_SOFTWARE) | the output file cannot be read or does not match any of the above patterns

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »